@@ -1,8 +1,9 @@
 //! [Church numerals](https://en.wikipedia.org/wiki/Church_encoding#Church_numerals)
 
-use term::*;
+use term::{Term, Error, abs, app};
+use term::Term::*;
 use term::Error::*;
-use church::booleans::*;
+use church::booleans::{tru, fls};
 use combinators::z;
 
 /// Produces a Church-encoded number zero.
@@ -895,7 +896,7 @@ mod tests {
     }
 
     #[test]
-    fn church_fac() {
+    fn church_factorial() {
         assert_eq!(beta(app!(fac(), 0.into()), NOR, 0, false), 1.into());
         assert_eq!(beta(app!(fac(), 1.into()), NOR, 0, false), 1.into());
         assert_eq!(beta(app!(fac(), 2.into()), NOR, 0, false), 2.into());
